@@ -65,6 +65,7 @@ impl fmt::Display for Os {
 #[serde(rename_all = "lowercase")]
 pub enum Arch {
     Aarch64,
+    Armv5teL,
     Armv6L,
     Armv7L,
     #[serde(alias = "ppc")]
@@ -85,6 +86,7 @@ pub enum Arch {
     Mipsel,
     Mips,
     Sparc64,
+    Sparcv9,
     LoongArch64,
 }
 
@@ -92,6 +94,7 @@ impl fmt::Display for Arch {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match *self {
             Arch::Aarch64 => write!(f, "aarch64"),
+            Arch::Armv5teL => write!(f, "armv5tel"),
             Arch::Armv6L => write!(f, "armv6l"),
             Arch::Armv7L => write!(f, "armv7l"),
             Arch::Powerpc => write!(f, "ppc"),
@@ -108,6 +111,7 @@ impl fmt::Display for Arch {
             Arch::Mipsel => write!(f, "mipsel"),
             Arch::Mips => write!(f, "mips"),
             Arch::Sparc64 => write!(f, "sparc64"),
+            Arch::Sparcv9 => write!(f, "sparcv9"),
             Arch::LoongArch64 => write!(f, "loongarch64"),
         }
     }
@@ -122,7 +126,7 @@ impl Arch {
         // MACHINE_ARCH	vs MACHINE_CPUARCH vs MACHINE section
         match self {
             Arch::Aarch64 => "arm64",
-            Arch::Armv6L | Arch::Armv7L => "arm",
+            Arch::Armv5teL | Arch::Armv6L | Arch::Armv7L => "arm",
             Arch::Powerpc | Arch::Powerpc64Le | Arch::Powerpc64 => "powerpc",
             Arch::X86 => "i386",
             Arch::X86_64 => "amd64",
@@ -130,6 +134,7 @@ impl Arch {
             Arch::Mips64el | Arch::Mips64 | Arch::Mipsel | Arch::Mips => "mips",
             // sparc64 is unsupported since FreeBSD 13.0
             Arch::Sparc64 => "sparc64",
+            Arch::Sparcv9 => "sparcv9",
             Arch::Wasm32 => "wasm32",
             Arch::S390X => "s390x",
             Arch::LoongArch64 => "loongarch64",
@@ -142,6 +147,7 @@ fn get_supported_architectures(os: &Os) -> Vec<Arch> {
     match os {
         Os::Linux => vec![
             Arch::Aarch64,
+            Arch::Armv5teL,
             Arch::Armv6L,
             Arch::Armv7L,
             Arch::Powerpc,
@@ -192,7 +198,7 @@ fn get_supported_architectures(os: &Os) -> Vec<Arch> {
         Os::Dragonfly => vec![Arch::X86_64],
         Os::Illumos => vec![Arch::X86_64],
         Os::Haiku => vec![Arch::X86_64],
-        Os::Solaris => vec![Arch::X86_64, Arch::Sparc64],
+        Os::Solaris => vec![Arch::X86_64, Arch::Sparc64, Arch::Sparcv9],
         Os::Emscripten | Os::Wasi => vec![Arch::Wasm32],
         Os::Aix => vec![Arch::Powerpc64],
         Os::Hurd => vec![Arch::X86, Arch::X86_64],
@@ -246,8 +252,8 @@ impl Target {
         let os = match platform.operating_system {
             OperatingSystem::Linux => Os::Linux,
             OperatingSystem::Windows => Os::Windows,
-            OperatingSystem::MacOSX { .. } | OperatingSystem::Darwin => Os::Macos,
-            OperatingSystem::Ios => Os::Ios,
+            OperatingSystem::MacOSX(_) | OperatingSystem::Darwin(_) => Os::Macos,
+            OperatingSystem::IOS(_) => Os::Ios,
             OperatingSystem::Netbsd => Os::NetBsd,
             OperatingSystem::Freebsd => Os::FreeBsd,
             OperatingSystem::Openbsd => Os::OpenBsd,
@@ -266,8 +272,10 @@ impl Target {
             Architecture::X86_64 | Architecture::X86_64h => Arch::X86_64,
             Architecture::X86_32(_) => Arch::X86,
             Architecture::Arm(arm_arch) => match arm_arch {
+                ArmArchitecture::Armv5te => Arch::Armv5teL,
                 ArmArchitecture::Arm | ArmArchitecture::Armv6 => Arch::Armv6L,
-                _ => Arch::Armv7L,
+                ArmArchitecture::Armv7 => Arch::Armv7L,
+                _ => bail!("The architecture {} is not supported", arm_arch),
             },
             Architecture::Aarch64(_) => Arch::Aarch64,
             Architecture::Powerpc => Arch::Powerpc,
@@ -288,6 +296,7 @@ impl Target {
                 _ => bail!("The architecture {} is not supported", mips32_arch),
             },
             Architecture::Sparc64 => Arch::Sparc64,
+            Architecture::Sparcv9 => Arch::Sparcv9,
             Architecture::LoongArch64 => Arch::LoongArch64,
             unsupported => bail!("The architecture {} is not supported", unsupported),
         };
@@ -355,6 +364,7 @@ impl Target {
     pub fn get_python_arch(&self) -> &str {
         match self.arch {
             Arch::Aarch64 => "aarch64",
+            Arch::Armv5teL => "armv5tel",
             Arch::Armv6L => "armv6l",
             Arch::Armv7L => "armv7l",
             Arch::Powerpc => "ppc",
@@ -370,13 +380,17 @@ impl Target {
             Arch::Mips64el | Arch::Mips64 => "mips64",
             Arch::Mipsel | Arch::Mips => "mips",
             Arch::Sparc64 => "sparc64",
+            Arch::Sparcv9 => "sparcv9",
             Arch::LoongArch64 => "loongarch64",
         }
     }
 
     /// Returns the extension architecture name python uses in `ext_suffix` for this architecture.
     pub fn get_python_ext_arch(&self, python_impl: InterpreterKind) -> &str {
-        if matches!(self.target_arch(), Arch::Armv6L | Arch::Armv7L) {
+        if matches!(
+            self.target_arch(),
+            Arch::Armv5teL | Arch::Armv6L | Arch::Armv7L
+        ) {
             "arm"
         } else if matches!(self.target_arch(), Arch::Powerpc64Le)
             && python_impl == InterpreterKind::PyPy
@@ -449,7 +463,8 @@ impl Target {
                     PlatformTag::manylinux2010()
                 }
             }
-            Arch::Armv6L
+            Arch::Armv5teL
+            | Arch::Armv6L
             | Arch::Wasm32
             | Arch::Riscv32
             | Arch::Riscv64
@@ -459,6 +474,7 @@ impl Target {
             | Arch::Mips
             | Arch::Powerpc
             | Arch::Sparc64
+            | Arch::Sparcv9
             | Arch::LoongArch64 => PlatformTag::Linux,
         }
     }
@@ -475,8 +491,10 @@ impl Target {
             | Arch::Mips64el
             | Arch::Mips64
             | Arch::Sparc64
+            | Arch::Sparcv9
             | Arch::LoongArch64 => 64,
-            Arch::Armv6L
+            Arch::Armv5teL
+            | Arch::Armv6L
             | Arch::Armv7L
             | Arch::X86
             | Arch::Wasm32
